@@ -1,12 +1,12 @@
 use best_macros::public_struct;
-#[cfg(feature = "wasm")]
+#[cfg(feature = "serde")]
 use {
     serde::{Serialize, Deserialize}
 };
 
 #[public_struct]
 #[derive(Clone)]
-#[cfg_attr(feature = "wasm", derive(Serialize, Deserialize))]
+#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 struct PlayerState {
     points: usize,
     front: Vec<usize>,
